PresenceError

Enum PresenceError 

pub enum PresenceError {
    InvalidState,
    InvalidDiff,
    InvalidPresence(String),
    InvalidMetas(String),
    InvalidMeta(String),
    MissingReference(String),
    BinaryPayload,
}
Invalid Phoenix Presence state, diff, or metadata.

Variants



InvalidState

A full state was not a JSON object.



InvalidDiff

A diff did not contain valid joins and leaves objects.



InvalidPresence(String)

The named presence entry was not an object.



InvalidMetas(String)

The named presence entry had no metas array.



InvalidMeta(String)

A meta belonging to the named entry was not an object.



MissingReference(String)

A meta belonging to the named entry had no string phx_ref.



BinaryPayload

Presence events cannot be decoded from binary payloads.