pub enum PresenceUpdate {
Ignored,
Pending,
Synced(PresenceDiff),
}Expand description
Result of applying a frame to a PresenceTracker.
Variants
Ignored
The frame was not a configured Presence event.
Pending
A diff was queued until a matching full state arrives.
Synced(PresenceDiff)
State was updated with the returned joins and leaves.