pub fn sync_presence_state(
state: &mut PresenceState,
new_state: PresenceState,
) -> Result<PresenceDiff, PresenceError>Expand description
Replaces state with a full server state and returns its joins and leaves.
pub fn sync_presence_state(
state: &mut PresenceState,
new_state: PresenceState,
) -> Result<PresenceDiff, PresenceError>Replaces state with a full server state and returns its joins and leaves.