pub struct PresenceTracker { /* private fields */ }Expand description
Applies Phoenix Presence state and diff frames in join-generation order.
Implementations
Sourceimpl PresenceTracker
impl PresenceTracker
Sourcepub fn with_events(
state_event: impl Into<String>,
diff_event: impl Into<String>,
) -> Self
pub fn with_events( state_event: impl Into<String>, diff_event: impl Into<String>, ) -> Self
Creates a tracker with application-specific state and diff event names.
Sourcepub fn state(&self) -> &PresenceState
pub fn state(&self) -> &PresenceState
Returns the current synchronized state.
Sourcepub fn apply(&mut self, frame: &Frame) -> Result<PresenceUpdate, PresenceError>
pub fn apply(&mut self, frame: &Frame) -> Result<PresenceUpdate, PresenceError>
Applies a Phoenix frame and returns its Presence effect.