pub struct TransportClose {
pub code: Option<u16>,
pub reason: String,
pub was_clean: bool,
}Expand description
Details reported when a transport connection closes.
Fields
code: Option<u16>WebSocket close code, if a close frame was received.
reason: StringHuman-readable close reason.
was_clean: boolWhether the transport considered the close handshake clean.
Implementations
Sourceimpl TransportClose
impl TransportClose
Sourcepub fn new(
code: Option<u16>,
reason: impl Into<String>,
was_clean: bool,
) -> Self
pub fn new( code: Option<u16>, reason: impl Into<String>, was_clean: bool, ) -> Self
Creates close details reported by a transport.
Sourcepub fn connection_ended() -> Self
pub fn connection_ended() -> Self
Creates an abnormal close for a stream that ended without a close frame.
Sourcepub fn should_reconnect(&self) -> bool
pub fn should_reconnect(&self) -> bool
Returns whether the managed client should reconnect this close by default.